// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_ui_components/src/domain/entities/component.dart';

abstract class CardComponent extends Component {
  const CardComponent({
    this.radius = 12,
    this.padding = 25,
    this.borderColors,
    this.backgroundColor,
    this.minSize = const Size(330, 230),
    this.maxSize = const Size(330, 530),
    this.shadow = const BoxShadow(
      blurRadius: 30,
      offset: Offset(0, 5),
      color: Color.fromRGBO(0, 0, 0, 0.05),
    ),
    this.background,
    super.key,
  });

  /// Card radius
  final double? radius;

  /// Padding and gaps of this card
  final double? padding;

  /// Border gradient color (from left to right)
  final List<Color>? borderColors;

  /// Card background color
  final Color? backgroundColor;

  /// Minimum size for this card
  final Size? minSize;

  /// Maximum size for this card
  final Size? maxSize;

  /// Drop shadow
  final BoxShadow? shadow;

  /// Background of the card
  final Widget? background;
}
