// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/gradients/gradient_text.dart';
import 'package:wyatt_ui_kit/src/core/extensions/theme_extensions.dart';
import 'package:wyatt_ui_kit/src/core/helpers/linear_gradient_helper.dart';

const _titlesLineSpacing = 5.0;

class InformationCardTitles extends StatelessWidget {
  const InformationCardTitles({
    this.title,
    this.subtitle,
    this.axis,
    super.key,
  });

  final TextWrapper? title;
  final TextWrapper? subtitle;
  final Axis? axis;

  @override
  Widget build(BuildContext context) => Column(
        crossAxisAlignment: axis == Axis.horizontal
            ? CrossAxisAlignment.start
            : CrossAxisAlignment.center,
        children: [
          if (title != null) ...[
            Text(
              title!.text,
              style: title!.style ?? context.textTheme.titleLarge,
            ).toGradient(
              LinearGradientHelper.fromNullableColors(title!.gradient),
            ),
          ],
          if (subtitle != null) ...[
            const Gap(_titlesLineSpacing),
            Text(
              subtitle!.text,
              style: subtitle!.style ?? context.textTheme.titleSmall,
            ).toGradient(
              LinearGradientHelper.fromNullableColors(subtitle!.gradient),
            ),
          ],
        ],
      );
}
